## **Journal of Sports Sciences**

**[ISSN: 0264-0414 (Print) 1466-447X (Online) Journal homepage: http://www.tandfonline.com/loi/rjsp20](http://www.tandfonline.com/loi/rjsp20)**

# **Validity and reliability of a low-cost digital** **dynamometer for measuring isometric strength of** **lower limb**

**Natalia Romero-Franco, Pedro Jiménez-Reyes & Juan A. Montaño-Munuera**

**To cite this article:** Natalia Romero-Franco, Pedro Jiménez-Reyes & Juan A. Montaño-Munuera
(2016): Validity and reliability of a low-cost digital dynamometer for measuring isometric
[strength of lower limb, Journal of Sports Sciences, DOI: 10.1080/02640414.2016.1260152](http://www.tandfonline.com/action/showCitFormats?doi=10.1080/02640414.2016.1260152)

**To link to this article:** [http://dx.doi.org/10.1080/02640414.2016.1260152](http://dx.doi.org/10.1080/02640414.2016.1260152)

Published online: 24 Nov 2016.

[Submit your article to this journal](http://www.tandfonline.com/action/authorSubmission?journalCode=rjsp20&show=instructions)

[View related articles](http://www.tandfonline.com/doi/mlt/10.1080/02640414.2016.1260152)

[View Crossmark data](http://crossmark.crossref.org/dialog/?doi=10.1080/02640414.2016.1260152&domain=pdf&date_stamp=2016-11-24)

Full Terms & Conditions of access and use can be found at
[http://www.tandfonline.com/action/journalInformation?journalCode=rjsp20](http://www.tandfonline.com/action/journalInformation?journalCode=rjsp20)

**Download by:** \[Athabasca University\] **Date:** 24 November 2016, At: 10:43

JOURNAL OF SPORTS SCIENCES, 2016
<http://dx.doi.org/10.1080/02640414.2016.1260152>

### Validity and reliability of a low-cost digital dynamometer for measuring isometric strength of lower limb

Natalia Romero-Franco \[a\], Pedro Jiménez-Reyes \[b\] and Juan A. Montaño-Munuera \[c\]

aNursery and Physiotherapy department, University of the Balearic Islands, Palma de Mallorca, Spain; bSports Science department, Catholic
University of San Antonio of Murcia, Murcia, Spain; \[c\] Physiotherapy department, Catholic University of San Antonio of Murcia, Murcia, Spain

ABSTRACT
Lower limb isometric strength is a key parameter to monitor the training process or recognise muscle
weakness and injury risk. However, valid and reliable methods to evaluate it often require high-cost
tools. The aim of this study was to analyse the concurrent validity and reliability of a low-cost digital
dynamometer for measuring isometric strength in lower limb. Eleven physically active and healthy
participants performed maximal isometric strength for: flexion and extension of ankle, flexion and
extension of knee, flexion, extension, adduction, abduction, internal and external rotation of hip. Data
obtained by the digital dynamometer were compared with the isokinetic dynamometer to examine its
concurrent validity. Data obtained by the digital dynamometer from 2 different evaluators and 2
different sessions were compared to examine its inter-rater and intra-rater reliability. Intra-class correlation (ICC) for validity was excellent in every movement (ICC > 0.9). Intra and inter-tester reliability was
excellent for all the movements assessed (ICC > 0.75). The low-cost digital dynamometer demonstrated
strong concurrent validity and excellent intra and inter-tester reliability for assessing isometric strength
in the main lower limb movements.

ARTICLE HISTORY
Accepted 7 November 2016

KEYWORDS

Exercise test; isometric contraction; lower extremity;
reliability; validity

Introduction

The isometric strength is one of the parameters that sports
professionals use to monitor improvements in strength following training and even recognise unbalanced strength in a
joint, which could facilitate injuries (Diamond et al., 2015;
Haas, Cooperstein, & Peterson, 2007; Khayambashi, Ghoddosi,
Straub, & Powers, 2015; Luedke, Heiderscheit, Williams, &
Rauh, 2015). Previous studies reported the isometric hip
abduction and external rotation strength as a parameter to
predict non-contact anterior cruciate ligament injury or higher
incidence of anterior knee pain (Diamond et al., 2015;
Khayambashi et al., 2015; Luedke et al., 2015). Similar results
were reported in knee and ankle region, which often correlated with residual symptoms of ankle sprain or femoropatellar
syndrome(Gabriner, Houston, Kirby, & Hoch, 2015; Milgrom,
Finestone, Eldad, & Shlamkovitch, 1991). In this sense, the
isokinetic dynamometer is a reliable and valid equipment
that has been used for measuring lower limb muscle strength
(Drouin, Valovich-mcLeod, Shultz, Gansneder, & Perrin, 2004;
Feiring, Ellenbecker, & Derscheid, 1990), but their cost and
difficult to transport hinder its employment for most of sports
professionals (Stark, Walker, Phillips, Fejer, & Beck, 2011).
Instead, manual muscle testing (MMT) are normally used
with scales graded from 0 to 5, but the validity and reliability
of this tool is amply argued (Haas et al., 2007). These reasons
led several authors to validate the hand-held dynamometer as
tool to measure the isometric strength for most of the body
regions (Stark et al., 2011).

Despite the great reduction in cost and the portable character of the hand-held dynamometer, it continues being economically inaccessible for many sports professionals, who
continue using the graded scales of the MMT according to
subjective criteria (Reese, 2013).

The low-cost 50 g precision digital dynamometer Carp
Spirit Water Queen® (France) allow the evaluation of the isometric strength on all sport contexts because it is easy to
transport, easy to handle, and very cost effective (≈40 €).
Therefore, the purpose of this study was to investigate the
concurrent validity and reliability of a low-cost and portable
digital dynamometer to measure the isometric strength of the
lower limb during the main movements.

Methods

Design

Three different sessions were completed. In the first session,
11 participants performed maximal isometric strength during
the main movements of the dominant lower limb. Strength
values were simultaneously provided by an isokinetic dynamometer and the low-cost digital dynamometer and were compared to evaluate the concurrent validity of the latter
instrument. A low-cost 50 g precision digital dynamometer

–
Carp Spirit Water Queen® (France) with 0 50 kg as range of
measurement and 10 Hz as sample rate was used. One week
later, all the participants participated in the second session
and completed the same series of maximal isometric strength,

CONTACT Natalia Romero-Franco <narf52@gmail.com> Nursery and Physiotherapy Department, University of the Balearic Islands, University Campus Beatriu de Pinos. Road Valldemossa, Km 7.5, Palma E-07122, Spain

© 2016 Informa UK Limited, trading as Taylor & Francis Group

2 N. ROMERO-FRANCO ET AL.

which were repeated after 1 week in the session 3. The sessions 1 and 2 were guided by the evaluator T1 and the session
3 was guided by the evaluator T2 to evaluate the intra-tester
and inter-tester reliability of the low-cost digital dynamometer, respectively. The dependent variables were the maximal isometric strength in the main lower limb movements.

Participants

Eleven healthy volunteers (4 women and 7 men; age:
27.9 ± 1.2 years; height: 1.77 ± 0.08 m; mass: 71.5 ± 10.8 kg)
participated in this study. As inclusion criteria, all participants
should be free from lower limb injuries from at least 6 months
and physically active (at least 3 sessions of physical activity per
week). Before the beginning of the study, all participants
signed the inform consent according the Declaration of
Helsinki (Holt, 2014). This study was approved by the ethical
committee of the local university: CEIH 201014-2.

Procedures

The protocol for measuring the maximal isometric strength in
every lower limb movements was strictly identical for the 3
sessions, although the testing order was always randomised
(Figure 1). After a full explanation of experimental procedures,
participants carried out 5 min of jogging (8 km · h \[−\]\[1\] ) as warmup prior to the isometric strength measurements. Then, the
body region of the subject that was going to be tested was
fixed to the low-cost digital dynamometer with a belt and
strap, and a little pillow between the strap and the body
region to avoid harming the subject. To carry out the test,
the digital dynamometer was always fix and placed perpendicular to the axis of the force exerted by the participants. In the
first session, the low-cost digital dynamometer was attached
to the arm of the isokinetic dynamometer BIODEX System Pro
4™ (with the software System 4 advance v.4.2, New York, USA)
in order to simultaneously obtain the isometric strength
values by both instruments. In the second and third sessions,
the low-cost digital dynamometer was attached to an espalier.
The movements tested were: flexion and extension of ankle,
knee and hip, as well as hip abduction and adduction, and
external and internal hip rotation. The details of every movement are shown in the Figure 1. All participants should perform a maximal isometric contraction during 3 s in every
movement, 2 trials each movement (the best one was collected), with 2 min of rest. Before starting to assess the isometric strength in each lower limb movement, digital
dynamometer was zeroed. The evaluator T1 recorded the
maximal isometric strength values showed by the low-cost
digital dynamometer in the sessions 1 and 2, and the evaluator T2 recorded the maximal isometric strength values showed
by the low-cost digital dynamometer in the session 3. Both
evaluators T1 and T2 were randomly selected from a higher
sample of sports professionals of the regional athletic club.

Values reported by isokinetic dynamometer were compared with the low-cost digital dynamometer during the first
session to investigate the concurrent validity of the latter
instrument. The intra-tester and inter-tester reliability were
evaluated by comparing the strength values reported by the

Figure 1. Isometric strength assessment for the different lower limb movement:
Ankle extension (a), ankle flexion (b), knee flexion (c), knee extension (d), hip
flexion (e), hip extension (f), hip internal rotation (g), hip external rotation (h),
hip abduction (i), hip adduction (j).

low-cost digital dynamometer during the sessions 1 and 2,
and sessions 1 and 3, respectively. All sessions were separated
by 1 week.

Statistical analyses

All data for the strength measurements are presented as mean
± standard deviation (SD). Several statistical analyses were
used to compare the low-cost dynamometer to the isokinetic
dynamometer for the measurement of strength during the

JOURNAL OF SPORTS SCIENCES 3

Figure 2. Validity between the low-cost dynamometer and the isokinetic dynamometer for the measurement of the strength during all the lower limb movements.
The identity line is represented by the discontinuous line, while the regression line is represented by the continuous black line.

main lower limb movements. First, to analyse the concurrent
validity of the low-cost dynamometer in comparison with the
isokinetic dynamometer, Pearson’s product-moment correlation coefficient with 95% confidence intervals (CIs), the analysis of the slope and y-intercept of the resultant regression lines
and the standard error of estimate (SEE) were used. Second, to
test the level of agreement between devices on the measurement of the aforementioned variables, the intra-class correla
–
tion (ICC) coefficient (2,1) and Bland Altman plots were
analysed (Figure 2). Third, to test the intra-tester reliability,
(ICC) (2,1), and standard error of measurement (SEM) with
95% CI were analysed. Concretely, it was investigated by
comparing the measurements reported by the digital dynamometer in the sessions 1 and 2, both guided by the evaluator
A. ICC (2,1) and SEM were also analysed to evaluate the intertester reliability by comparing the measurements reported by
the digital dynamometer in the sessions 1 and 3, guided by
the evaluator A and B, respectively. The ICC was interpreted as

– –
almost perfect (0.81 1.00), substancial (0.61 0.80), moderate

– – –
(0.41 0.60), fair (0.21 0.40), slight (0.00 0.20), or poor (\<0.0)
(Landis and Koch, 1977).

Data were analysed using SPSS for Windows, version 19
(SPSS, Inc., Chicago, USA). Significance was determined at

P \< 0.05.

Results

Session 1: concurrent validity

Table 1 shows the isometric strength values reported by the
isokinetic dynamometer and the low-cost digital dynamometer in the main movement of lower limb.

An almost perfect correlation between the low-cost dynamometer and the isokinetic dynamometer for the measurement
of strength was observed for all lower limb movements
(r > 0.941, SEE \< 1.04 P \< 0.001) (Figure 2).

Also, an almost perfect agreement between the values of
strength obtained with both the low-cost dynamometer and
the isokinetic dynamometer was observed as revealed by the
ICC for all the lower limb movements (ICC > 0.9, P \< 0.001) and
Bland–Altman plots (Figure 3). No statistically significant differences between the 2 instruments on the measurement of

Table 1. Concurrent validity of isokinetic dynamometer and the low-cost digital dynamometer for isometric strength estimation.

Strength values Isokinetic Low-cost
(N) \[b\] dynamom \[a\] dynamom \[a\] SEE

Strength values Isokinetic Low-cost r ICC
(N) \[b\] dynamom \[a\] dynamom \[a\] SEE (95% CI) (95% CI)

Ankle flexion 2.8 ± 1.1 2.8 ± 1.2 1.00 0.994 (0.984–1.000)*0.993 (0.976–9.98)*
Ankle extension 1.9 ± 0.6 1.8 ± 0.6 1.00 0.996 (0.987–0.999)*0.995 (0.980–0.999)*
Knee flexion 1.9 ± 0.9 1.9 ± 0.9 1.00 1.000 (0.998–1.000)*0.994 (0.977–0.998)*
Knee extension 3.3 ± 0.7 3.2 ± 0.7 0.99 0.996 (0.980–1.000)*1.000 (0.999–1.000)*
Hip flexion 2.7 ± 0.6 2.6 ± 0.6 0.99 0.998 (0.996–1.000)*0.988 (0.957–0.997)*
Hip extension 3.4 ± 0.8 3.3 ± 0.8 0.97 0.988 (0.878–0.999)*0.998 (0.994–1.0)*
Hip abduction 2.2 ± 0.6 2.0 ± 0.6 0.97 0.974 (0.922–0.995)*0.972 (0.901–0.992)*
Hip adduction 2.2 ± 0.4 2.1 ± 0.3 0.98 0.988 (0.942–0.998)*0.982 (0.933–0.955)*
Hip int. rotation 1.5 ± 0.3 1.5 ± 0.3 0.92 0.941 (0.857–0.996)*0.941 (0.797–0.984)*
Hip ext. rotation 1.5 ± 0.3 1.4 ± 0.3 0.99 0.999 (0.996–1.000)*0.998 (0.993–0.999)*

r

(95% CI)

CI: confidence interval; ICC: intra-class correlation; N: Newton; r: Pearson correlation; SEE: standard error of the estimate.
\*P \< 0.001.
avalues given as mean ± standard deviation.
bvalues normalised to body mass (kg).

4 N. ROMERO-FRANCO ET AL.

Figure 3. Bland–Altman plots for the low-cost dynamometer and isokinetic dynamometer during the lower limb movements: Ankle flexion (a), ankle extension (b),
knee flexion (c), knee extension (d), hip flexion (e), hip extension (f), hip abduction (g), hip adduction (h), hip internal rotation (i), hip external rotation (j).

strength were observed in any lower limb movement (difference of means for all movements \<1.44, P > 0.05).

Sessions 2 and 3: intra-tester and inter-tester reliability

Table 2 shows the isometric strength values reported by the lowcost digital dynamometer in sessions 1, 2, and 3. The intra-tester

reliability of the method using the digital dynamometer to assess
the isometric strength of the main lower limb movement was
almost perfect for all movements (ICC > 0.88; SEM \< 16.3;
P \< 0.001). Similar results were found for the inter-tester reliability, that was almost perfect for all the lower limb movements
(ICC > 0.83, SEM \< 11.9, P ≤ 0.002), except for hip abduction, that
was substantial (ICC = 0.764, SEM = 7.39, P = 0.008).

Table 2. Reliability measures for the digital dynamometer.

JOURNAL OF SPORTS SCIENCES 5

Intra-tester reliability Inter-tester reliability

Strength values Session 1
(N) \[b\] (T1) \[a\]

Session 3
(T1ʹ) \[a\] (T2) \[a\]

Strength values Session 1 Session 2 Session 3 ICC ICC
(N) \[b\] (T1) \[a\] (T1ʹ) \[a\] (T2) \[a\] (95% CI) SEM (95% CI) SEM

Ankle flexion 2.8 ± 1.2 2.8 ± 1.2 2.6 ± 1.2 0.970 (0.894–0.992)*7.2 0.994 (0.972–0.999)* 3.9
Ankle extension 1.8 ± 0.6 1.8 ± 0.5 1.6 ± 0.5 0.886 (0.633–0.968)*11.2 0.878 (0.510–0.974)* 11.9
Knee flexion 1.9 ± 0.9 2.0 ± 0.9 1.9 ± 1.1 0.979 (0.924–0.994)*8.9 0.991 (0.957–0.998)* 6.8
Knee extension 3.2 ± 0.7 3.2 ± 0.6 3.4 ± 0.9 0.938 (0.789–0.983)*10.4 0.983 (0.920–0.997)* 10.6
Hip flexion 2.6 ± 0.6 2.5 ± 0.6 2.4 ± 0.6 0.910 (0.701–0.975)*16.3 0.950 (0.771–0.990)* 11.4
Hip extension 3.3 ± 0.8 3.5 ± 0.7 3.5 ± 0.9 0.984 (0.941–0.996)*3.9 0.993 (0.964–0.999)* 4.8
Hip abduction 2.0 ± 0.6 2.1 ± 0.6 2.2 ± 0.7 0.930 (0.762–0.981)*8.4 0.764 (0.199–0.948)* 7.4
Hip adduction 2.1 ± 0.3 2.2 ± 0.4 2.2 ± 0.3 0.882 (0.623–0.967)*6.1 0.838 (0.389–0.965)* 7.9
Hip int. rotation 1.5 ± 0.3 1.5 ± 0.3 1.4 ± 0.4 0.892 (0.649–0.970)*9.7 0.865 (0.470–0.972)* 11.2
Hip ext. rotation 1.4 ± 0.3 1.4 ± 0.3 1.3 ± 0.3 0.974 (0.906–0.993)*4.8 0.865 (0.470–0.971)* 8.6

Session 2
(T1) \[a\] (T1ʹ) \[a\]

ICC
(T2) \[a\] (95% CI) SEM

Ext.: external; Int.: internal; N: Newton; SEM: standard error of the measurement; T1: tester 1, first session; T1’: tester 1, second session; T2: tester 2.
\*P \< 0.001.
avalues given as mean ± standard deviation.
bvalues normalised to body mass (kg).

Discussion

The main findings of the present study showed that the lowcost digital dynamometer demonstrated excellent concurrent
validity compared with isokinetic dynamometer and also
excellent inter-tester and intra-tester reliabilities for measuring
maximal isometric strength in the main movements of lower
limbs. These findings are especially relevant in the field of
sport due to the importance of the isometric strength as
parameter to monitor the training process and even to detect
strength imbalance as parameter to predict injury risk.

In the light of previous studies that evaluated the reliability of
hand-held dynamometer, our findings are similar to those shown
by Cadogan et al, Celik et al., and Andersen et al. (Andersen,
Christensen, Samani, & Madeleine, 2014; Cadogan, Laslett, Hing,
McNair, & Williams, 2011; Celik, Dirican, & Baltaci, 2012) Cadogan
evaluated the inter and intra-rater reliability of a new hand-held
dynamometer with the ability to standardise overpressure force
during passive range of motion tests, and concluded that this
new method was reliable to measure peak isometric force
(Cadogan et al., 2011). Similarly, Celik et al. assessed the intrarater reliability of hand-held dynamometer to estimate the
shoulder and scapular muscles strength corrected by the body
mass index. These authors reported reliable results from this tool
for healthy population, as well as for patients with impingement
syndrome (Celik et al., 2012). In agreement, Andersen et al.
demonstrated reliable outcomes for the between-day reliability
of a hand-held dynamometer to estimate isometric submaximal
force in the shoulder joint (Andersen et al., 2014). As the present
study, these previous studies evaluated and ensured the reliability of alternative methods to the traditional hand-held dynamometer during isometric contractions.

Regarding the isometric strength as variable to monitor the
training process, sport professionals often assess the improvements in strength of the participants following the training.
Stone et al. demonstrated that maximum isometric strength
was strongly associated with peak force and peak power, even
for sport-specific dynamic explosive actions at relatively light
loads like snatch or shot-put (Stone et al., 2003). Supporting
these findings, McGuidan et al. correlated the maximal isometric strength with 1 repetition maximum (1RM) in college
athletes (McGuigan, Winchester, & Erickson, 2006). For this

reason, several authors have evaluated maximal isometric
strength to determine the effects on performance following
trainings like whole-body vibration, eccentric exercises, or
even stretching (Byrne & Eston, 2002; Knudson & Noffal,
2005). Therefore, the assessment of isometric strength gives
sports professional key information about the participants’
status. On the other hand, although it has been shown that
maximum isometric strength, mainly during open kinetic
chain, may be not the most useful variable for predicting
dynamic performance like jump or sprint, it might supplement
other dynamic tests (Requena et al., 2009; Thomas, Jones,
Rothwell, Chiang, & Comfort, 2015).

Another important role of the maximum isometric strength
during the training session is linked to the fatigue. If we considered that fatigue is reflected as any performance decrease under
certain conditions, the maximum isometric strength is an indicator of fatigue that help control the training session (Gandevia,
Allen, & McKenzie, 1995; Vøllestad, 1997). Thus, this affordable
tool might help sports professional easily assess the isometric
strength of the participants in field situations and design appropriate conditioning planning.

In terms of injury risk, prospective studies like that carried out
by Khayambashi et al. demonstrated that a weak hip musculature,
mainly abductor and external rotators, may predict non-contact
knee injuries (Khayambashi et al., 2015), or Culvernor et al. who
estimated the isometric strength of thigh as a risk factor that
predict the need of knee replacement surgery in women
(Culvenor, Wirth, Ruhdorfer, & Eckstein, 2015). Therefore, we consider important the present findings because of the role of the
muscle weakness in the incidence of lower limb injuries

Despite the usefulness and high frequency of the isokinetic
dynamometer for sports professionals, we propose a new tool,
more affordable and equally portable that supplements the
isokinetic dynamometer due to the strong concurrent validity
and reliability reported for all the lower limb movement evaluated in the present study. While isokinetic dynamometer is
able to record force time series and thereby compute rate
force development, entropy measures and force steadiness,
the low-cost dynamometer provides measurements of isometric strength, to monitor the training in field situations.

As major limitation of the present study, the 50 kg as maximum capacity of the digital dynamometer could limit the

6 N. ROMERO-FRANCO ET AL.

evaluation for athletes with high rates of force in certain movements. Also, the current findings cannot be generalised to other
population such as athletes or patients. Future studies should
consider evaluating a digital dynamometer with higher capacity
and recruit athletes and patients to include this tool in the high
performance and clinical fields, respectively.

As practical application, the low-cost digital dynamometer
provides a method with excellent concurrent validity and reliability to assess the isometric strength for the main lower limb movements. Sports professionals should consider this method to
evaluate the isometric strength in field situation due to the portability of this tool, increasing the validity and reliability of these
measures to supplement the information provided by the isokinetic dynamometer. Also, the low-cost character of this tool makes
it an affordable instrument that any sports professional can obtain.
Thus, it can be used with confidence to monitor within-group
changes in longitudinal assessments (i.e., training process), and
between-group differences in cross-sectionals comparisons (i.e.,
between healthy participants with different strength levels).

Conclusion

The low-cost digital dynamometer is a valid and reliable
method for assessing isometric strength in the main lower
limb movements. The portable and simple nature of this
method allows sports professionals to evaluate the isometric
strength during the training process even under field conditions in order to optimise and orientate training programmes.

Disclosure statement

No potential conflict of interest was reported by the authors.

References

Andersen, K. S, Christensen, B. H, Samani, A, & Madeleine, P. (2014).

Between-day reliability of a hand-held dynamometer and surface electromyography recordings during isometric submaximal contractions in
different shoulder positions.. Journal of Electromyography and
[Kinesiology. 24(5), 579–587. doi:10.1016/j.jelekin.2014.05.007](http://dx.doi.org/10.1016/j.jelekin.2014.05.007)
Byrne, C., & Eston, R. (2002). Maximal-intensity isometric and dynamic

exercise performance after eccentric muscle actions. Journal of Sports
[Science, 20(12), 951–959. doi:10.1080/026404102321011706](http://dx.doi.org/10.1080/026404102321011706)
Cadogan, A, Laslett, M, Hing, W, McNair, P, & Williams, M. (2011). Reliability

of a new hand-held dynamometer in measuring shoulder range of
motion and strength. Manual Therapy. 16(1), 97–101.
Celik, D, Dirican, A, & Baltaci, G. (2012). Intrarater reliability of assessing

strength of the shoulder and scapular muscles. Journal Of Sport
Rehabilitation, Technical Notes, 3, 1–5.
Culvenor, A., Wirth, W., Ruhdorfer, A., & Eckstein, F. (2015). Thigh muscle

strength predicts knee replacement risk independent of radiographic
disease and pain in women - data from the Osteoarthritis initiative.
[Arthritis & Rheumatology, 68(5), 1145–1155. doi:10.1002/art.39540](http://dx.doi.org/10.1002/art.39540)
Diamond, L. E., Wrigley, T. V., Hinman, R. S., Hodges, P. W., O’Donnell, J.,

Takla, A., & Bennell, K. L. (2015). Isometric and isokinetic hip strength
and agonist/antagonist ratios in symptomatic femoroacetabular impingement. Journal of Science and Medicine in Sport, 19(9), 696–701.
[doi:10.1016/j.jsams.2015.10.002](http://dx.doi.org/10.1016/j.jsams.2015.10.002)

Drouin, J. M., Valovich-mcLeod, T. C., Shultz, S. J., Gansneder, B. M., & Perrin, D.

H. (2004). Reliability and validity of the Biodex system 3 pro isokinetic
dynamometer velocity, torque and position measurements. European
[Journal of Applied Physiology, 91(1), 22–29. doi:10.1007/s00421-003-0933-0](http://dx.doi.org/10.1007/s00421-003-0933-0)
Feiring, D. C., Ellenbecker, T. S., & Derscheid, G. L. (1990). Test-retest reliability

of the biodex isokinetic dynamometer. Journal of Orthopaedic & Sports
[Physical Therapy, 11(7), 298–300. doi:10.2519/jospt.1990.11.7.298](http://dx.doi.org/10.2519/jospt.1990.11.7.298)
Gabriner, M. L., Houston, M. N., Kirby, J. L., & Hoch, M. C. (2015).

Contributing factors to star excursion balance test performance in
individuals with chronic ankle instability. Gait & Posture, 41(4), 912–
[916. doi:10.1016/j.gaitpost.2015.03.013](http://dx.doi.org/10.1016/j.gaitpost.2015.03.013)
Gandevia, S. C., Allen, G. M., & McKenzie, D. K. (1995). Central fatigue.

Critical issues, quantification and practical implications. Advances in
Experimental Medicine and Biology, 384, 281–294.
Haas, M., Cooperstein, R., & Peterson, D. (2007). Disentangling manual

muscle testing and Applied Kinesiology: Critique and reinterpretation
[of a literature review. Chiropractic & Osteopathy, 15, 11. doi:10.1186/](http://dx.doi.org/10.1186/1746-1340-15-11)

[1746-1340-15-11](http://dx.doi.org/10.1186/1746-1340-15-11)

Holt, G. R. (2014). Declaration of Helsinki-the world’s document of con
science and responsibility. Southern Medical Journal, 107(7), 407.
[doi:10.14423/SMJ.0000000000000131](http://dx.doi.org/10.14423/SMJ.0000000000000131)

Khayambashi, K., Ghoddosi, N., Straub, R. K., & Powers, C. M. (2015). Hip

muscle strength predicts noncontact anterior cruciate ligament injury
in male and female athletes: A prospective study. The American Journal
[of Sports Medicine. doi:10.1177/0363546515616237](http://dx.doi.org/10.1177/0363546515616237)
Knudson, D., & Noffal, G. (2005). Time course of stretch-induced isometric

strength deficits. European Journal of Applied Physiology, 94(3), 348–351.
[doi:10.1007/s00421-004-1309-9](http://dx.doi.org/10.1007/s00421-004-1309-9)

Landis, J. R., & Koch, G. G. (1977) The measurement of observer agreement

for categorical data. Biometrics, 33(1):159–174.
Luedke, L. E., Heiderscheit, B. C., Williams, D. S., & Rauh, M. J. (2015).

Association of isometric strength of hip and knee muscles with injury
risk in high school cross country runners. International Journal of Sports
Physical Therapy, 10(6), 868–876.
McGuigan, M. R., Winchester, J. B., & Erickson, T. (2006). The importance of

isometric maximum strength in college wrestlers. Journal of Sports
Science and Medicine, 5(CSSI), 108–113.
Milgrom, C., Finestone, A., Eldad, A., & Shlamkovitch, N. (1991).
Patellofemoral pain caused by overactivity. A prospective study of risk
factors in infantry recruits. The Journal of Bone & Joint Surgery, 73(7),
[1041–1043. doi:10.2106/00004623-199173070-00012](http://dx.doi.org/10.2106/00004623-199173070-00012)

Reese, N. B. (2013). Muscle and sensory testing. USA: Elsevier Health

Sciences.

Requena, B., Gonzalez-Badillo, J. J., De Villareal, E. S., Ereline, J., Garcia,

I., Gapeyeva, H., & Paasuke, M. (2009). Functional performance,
maximal strength, and power characteristics in isometric and
dynamic actions of lower extremities in soccer players. The Journal
[of Strength & Conditioning Research, 23(5), 1391–1401. doi:10.1519/](http://dx.doi.org/10.1519/JSC.0b013e3181a4e88e)
[JSC.0b013e3181a4e88e](http://dx.doi.org/10.1519/JSC.0b013e3181a4e88e)

Stark, T., Walker, B., Phillips, J. K., Fejer, R., & Beck, R. (2011). Hand-held

dynamometry correlation with the gold standard isokinetic dynamo[metry: A systematic review. Pm&R, 3(5), 472–479. doi:10.1016/j.](http://dx.doi.org/10.1016/j.pmrj.2010.10.025)
[pmrj.2010.10.025](http://dx.doi.org/10.1016/j.pmrj.2010.10.025)
Stone, M. H., Sanborn, K., O’Bryant, H. S., Hartman, M., Stone, M. E., Proulx,

C., . . . Hruby, J. (2003). Maximum strength-power-performance relationships in collegiate throwers. The Journal of Strength & Conditioning
Research, 17(4), 739–745.
Thomas, C., Jones, P. A., Rothwell, J., Chiang, C. Y., & Comfort, P.

(2015). An investigation into the relationship between maximum
isometric strength and vertical jump performance. The Journal of
[Strength & Conditioning Research, 29(8), 2176–2185. doi:10.1519/](http://dx.doi.org/10.1519/JSC.0000000000000866)

[JSC.0000000000000866](http://dx.doi.org/10.1519/JSC.0000000000000866)

Vøllestad, N. K. (1997). Measurement of human muscle fatigue. Journal

[of Neuroscience Methods, 74(2), 219–227. doi:10.1016/S0165-0270(97)](<http://dx.doi.org/10.1016/S0165-0270(97)02251-6>)

[02251-6](<http://dx.doi.org/10.1016/S0165-0270(97)02251-6>)
